import files.payload;
import io.restassured.RestAssured;
import io.restassured.http.ContentType;
import io.restassured.path.json.JsonPath;
import io.restassured.response.Response;
import io.restassured.response.ValidatableResponse;
import org.hamcrest.CoreMatchers;
import org.hamcrest.Matchers;
import org.json.simple.JSONObject;
import org.testng.Assert;
import org.testng.annotations.Test;
import static io.restassured.RestAssured.*;
import static org.hamcrest.Matchers.equalTo;


public class API_Test_Reqres {
    @Test
    void testGet() {
        Response res = RestAssured.get("https://reqres.in/api/users?page=2");
        int code= res.getStatusCode();
        System.out.println("Status Code:"+code);
        System.out.println("Body :"+res.getBody().asString());
        System.out.println("Time taken :"+res.getTime());
        System.out.println("Header:"+res.getHeaders());
        ValidatableResponse v=res.then();
         v.time(Matchers.lessThan(1000L));
        Assert.assertEquals(200,code);
    }

    @Test
    void get(){
                 given()
                .when().
                        get("https://reqres.in/api/users?page=2").
                        then().statusCode(200).
                         body("data.id[0]", equalTo(7)).
                         body("data.email[1]",equalTo("lindsay.ferguson@reqres.in")).
                         body("data.first_name[3]",equalTo("Byron")).
                         body("data.last_name[5]",equalTo("Howell"));

    }


    @Test
    void testPost() {

        RestAssured.baseURI = "https://reqres.in/";
        String response = given().log().all().headers("Content-Type", "application/json").body(payload.postBody())
                .when().post("/api/users")
                .then().log().all().assertThat().statusCode(201).body("name", CoreMatchers.equalTo("morpheus")).extract().response().asString();
        System.out.println(response);
        JsonPath js=new JsonPath(response);
        String Id= js.getString("id");
        System.out.println(Id);

    }
    @Test
    void testPatch(){

        JSONObject dataSet=new JSONObject();
        dataSet.put("name","Rahim");
        dataSet.put("Work","Testing");
        System.out.println(dataSet.toJSONString());
        given().contentType(ContentType.JSON).accept(ContentType.JSON)
                .body(dataSet.toJSONString())
                .when().patch("https://reqres.in/api/users/2")
                .then().log().all().statusCode(200);
    }

    @Test
    void testPut(){

        JSONObject dataSet=new JSONObject();
        dataSet.put("name","Rahim");
        dataSet.put("Work","Testing");
        System.out.println(dataSet.toJSONString());
        given().contentType(ContentType.JSON).accept(ContentType.JSON)
                .body(dataSet.toJSONString())
                .when().put("https://reqres.in/api/users/2")
                .then().log().all().statusCode(200);
    }

    @Test
    void testDelete(){

        given()
                .when().delete("https://reqres.in/api/users/2")
                .then().statusCode(204);
    }

    @Test
    void testOption(){

        given()
                .when().options("https://reqres.in/api/users/2")
                .then().log().all().statusCode(204);
    }

    @Test
    void testHeader(){

        given()
                .when().head("https://reqres.in/api/users/2")
                .then().log().all().statusCode(200);
    }


}





